=======
Credits
=======

Development Lead
----------------

* Team Ozero <elgalu3@gmail.com>

Contributors
------------

* Suhas SG <jargnar@gmail.com>
    https://github.com/jargnar

* Onur Yilmaz <yilmazonur7@gmail.com>
    https://github.com/oyilmaz

* Dmitry Goryunov <d.f.goryunov@gmail.com>
    https://github.com/dmigo

* Leo Gallucci <elgalu3@gmail.com>
    https://github.com/elgalu

* Sergii Kamenskyi <sergukam@gmail.com>
    https://github.com/SergKam
